@@ -88,7 +88,8 @@ function move_task(&$task,$table_now,$table_new,$msg_OK,$msg_NG){
   $task_new =& $task_handler->create();
 
   $task_new->setVar('task_title', $task->getVar('task_title') );
-  $task_new->setVar('task_detail', $task->getVar('task_detail') );
+  $br=array("&lt;br /&gt;","<br />");					 			//ʤ\nפ<br />פˤʤΤǡ
+  $task_new->setVar('task_detail', str_replace( $br,"\n" ,$task->getVar('task_detail') ) );	//ִ
   $task_new->setVar('task_deadline', $task->getVar('task_deadline') );
   $task_new->setVar('task_priority', $task->getVar('task_priority') );
   $task_new->setVar('task_status', $task->getVar('task_status') );
